# pyd2v
A Python Parser for DGMPGDec's D2V Project Files

`pip install pyd2v`

<p align="center">
<a href="https://python.org"><img src="https://img.shields.io/badge/python-3.6%2B-informational?style=flat-square" /></a>
<a href="https://github.com/rlaPHOENiX/pyd2v/blob/master/LICENSE"><img alt="GitHub license" src="https://img.shields.io/github/license/rlaPHOENiX/pyd2v?style=flat-square"></a>
<a href="https://www.codefactor.io/repository/github/rlaphoenix/pyd2v"><img src="https://www.codefactor.io/repository/github/rlaphoenix/pyd2v/badge" alt="CodeFactor" /></a>
<a href="https://www.codacy.com/manual/rlaPHOENiX/pyd2v?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=rlaPHOENiX/pyd2v&amp;utm_campaign=Badge_Grade"><img src="https://api.codacy.com/project/badge/Grade/574e843d9e044dcbbc2743cd8092148a"/></a>
<a href="https://github.com/rlaPHOENiX/pyd2v/issues"><img alt="GitHub issues" src="https://img.shields.io/github/issues/rlaPHOENiX/pyd2v?style=flat-square"></a>
<a href="http://makeapullrequest.com"><img src="https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square"></a>
</p>

## Documentation

### Quick Example

```
# pip install pyd2v
from pyd2v import D2V

# ...

# Choose Input File
input_file = "/home/user/Desktop/video.d2v"
# Parse Input File
d2v = D2V.parse(file_path=input_file)
# Print D2V Options, which will be shown with the accessible variable names.
# Data will not be printed as it will be too large
print(d2v)
# Print Media Files
print(d2v.header.videos)
# Print Frame Rate
print(d2v.settings.frame_rate)
# Print first frame data
print(d2v.data.frames[0])
```

#### parse
Send a D2V to a D2V object to be parsed. Nothing will be returned, if failure it will raise a ValueError Exception. If successful, three options will be available, `header`, `settings` and `data` which can be accessed via `d2v_obj.header`.

`D2V.parse(str file_path)`
* file_path: File path to DGIndex Project File (`.d2v` extension)